@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 176 $
+# Revision: $Rev: 212 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -24,6 +24,7 @@
 #-- imports --------------------------------------------------------------------
 import logging
 import os
+import re
 
 from copy import deepcopy
 from os.path import join as fjoin, exists as fexists
@@ -35,7 +36,7 @@ from types import DictType, ModuleType
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 176 $
+# Revision: $Rev: 212 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -84,6 +85,12 @@ CONFIG_TEXT = """\
 
 #-- default definitions
 
+# The version number is used internally to decide wether a manual
+# upgrade or extension of the configuration file is necessary.
+
+version = %(version)s
+
+
 # logLevel is a dictionary, mapping class- and module names to
 # a constant which defines the minimum type of log-message that
 # will pass to log-output. Valid values in ascending order are:
@@ -287,6 +294,17 @@ autoScriptOnNew = %(autoScriptOnNew)s
 embeddedImage = %(embeddedImage)s
 
 
+# When adding pictures they are saved under the default path \"filenamePrefix\"
+# (see below). If you maintain several Databases you will need to change the
+# path depending on which DB is currently opened, otherwise pictures overwrite
+# eachother.
+# If set to \"True\" this option will cause a dialog window to popup and
+# ask for the path to save the image to.
+# Default: True
+
+queryPathOnLinkedImage = %(queryPathOnLinkedImage)s
+
+
 # imageFormat defines the format which is used to save both internal and
 # external images to. Supported output formats include:
 # JPEG, BMP, PBM, PGM, PNG, PPM, XBM, XPM
@@ -297,17 +315,14 @@ imageFormat = %(imageFormat)s
 
 
 # When images are saved externally, the variable filenamePrefix defines
-# the path and prefix used when storing images. Path and filename may be
-# set to any valid values, but a '%%d' format specifier must be contained
-# somewhere in the filename. This is replaced with the record ID as the
-# picture is saved.
-# If the path does not exist, it will be created recursively. Relative path
-# names are relative to the currently opened file.
-# The default value will put the files in the directory \"pictures\"
-# from the current working directory and let the record ID be zero-prefixed
-# to four decimal places.
-# The file extention is added automatically according to the file format
-# specified above.
+# the path and prefix used to store images.
+# Two substitutions may be used to make the automatically generated
+# filename dependent on the current input file and the record number:
+#   %%(db)s     is replaced by the basename of the current input file
+#   %%(no)d     is replaced by the record number of the movie
+#              use %%(no)04d for 4-digit, zero prefixed numbers
+#
+# Default: %%(db)s_pictures/movie_%%(no)04d
 
 filenamePrefix = %(filenamePrefix)s
 
@@ -328,7 +343,7 @@ sortColumn = %(sortColumn)s
 # comparison function in Python introduces a nagging delay each time the
 # display is sorted, which was unacceptable.
 # If you'd rather remove the leading zeros, set this to False.
-# Default: True
+# Default: False
 
 zeroPrefix_patch = %(zeroPrefix_patch)s
 
@@ -375,6 +390,8 @@ defaultScript = %(defaultScript)s
 class _Settings0(dict):
     """defines first element in configuration chain"""
     default = {
+        'version': '0.1',
+
         'logLevel': {'<none>'                : logging.DEBUG,
                      'default'               : logging.DEBUG,
                      '__main__'              : logging.DEBUG,
@@ -470,11 +487,12 @@ class _Settings0(dict):
         'autoScriptOnNew': False,
         
         'embeddedImage': False,
+        'queryPathOnLinkedImage': True,
         'imageFormat': 'JPEG',
-        'filenamePrefix': u"pictures/movie_%04d",
+        'filenamePrefix': u"%(db)s_pictures/movie_%(no)04d",
         
         'sortColumn': 0,
-        'zeroPrefix_patch': True,
+        'zeroPrefix_patch': False,
         
         'scripts':{'[Merkosh Special]':
                    (u"all available fields from IMDB (US)\n+ medium sized picture from Amazon\n+ big picture from filmposter-archiv.de",
@@ -518,6 +536,23 @@ class _Settings0(dict):
         dict.update(self, _Settings0.default)
 
 
+    def selfUpdate(self, toDict, fromDict):
+        """recursively updates toDict from fromDict"""
+        # toDict is initially <self> == default config settings
+        # fromDict contains all configurations from the user config file
+
+        # update all available fields from fromDict
+        for k in fromDict.keys():
+            # if both source and destination types are dicts: traverse
+            if ((type(fromDict[k]) is DictType) and (type(toDict[k]) is DictType)):
+                # recurse
+                self.selfUpdate(toDict[k], fromDict[k])
+
+            # if value is no dictionary: use value from config file
+            elif (not type(fromDict[k]) is ModuleType):
+                toDict[k] = fromDict[k]
+
+        
     def asText(self):
         """returns a dict which interpolates configText"""
         # whats needed to be imported
@@ -532,7 +567,8 @@ class _Settings0(dict):
                     'ejectOnUnmount', 'defaultHistory', 'addHistoryFromRecords',
                     'recordDefault', 'autoScanAutoMountOnNew', 'autoScanOnNew',
                     'autoScriptOnNew', 'deepcopyOnCopy', 'defaultFile',
-                    'reopenLastFile', 'recentFiles']:
+                    'reopenLastFile', 'recentFiles', 'queryPathOnLinkedImage',
+                    'version']:
             defs[key] = pformat(self[key])
 
         # class instance 
@@ -542,6 +578,31 @@ class _Settings0(dict):
         return defs
 
 
+class _Settings1(_Settings0):
+    """extends previous settings object by a new filenamePrefix format
+
+    This was introduced with log format version 0.1.
+    """
+    def __init__(self):
+        # run parent constructor
+        super(_Settings1, self).__init__()
+
+    def selfUpdate(self, toDict, fromDict):
+        # update configuration the usual way
+        super(_Settings1, self).selfUpdate(toDict, fromDict)
+
+        # change filenamePrefix format:
+        #   previously a %<digits>d was replaced by the movie ID
+        #   now the correct format is: %(no)<digits>d
+        if (not fromDict.has_key('version')):
+            # search for previous configuration
+            result = re.sub(r'\%(\d*)d', # pattern
+                            r'%(no)\1d', # replacement
+                            self['filenamePrefix'])
+            self['filenamePrefix'] = result
+                
+        
+
 #-- main class for config format -----------------------------------------------
 # If the configuration format needs to be changed and in order to keep
 # a transparent layer of compatibility for seemless upgrade the following
@@ -552,7 +613,7 @@ class _Settings0(dict):
 # a way that when calling the parent's asText() or update() method the
 # interface to the old-style configuration is maintained and the return
 # value reflects the current state of the configuration.
-class _Settings(_Settings0):
+class _Settings(_Settings1):
     """encapsulates loading, updating and saving of global program defaults
 
     Compared to the _Pref class, this contains the global, cross-class
@@ -573,26 +634,8 @@ class _Settings(_Settings0):
         # runtime variables
         self.userdir = fjoin(os.environ['HOME'], '.lmc')
         self.configFile = fjoin(self.userdir, "lmc.conf")
-        self.updateStack = []
         
 
-    def selfUpdate(self, toDict, fromDict):
-        """recursively updates toDict from fromDict"""
-        # toDict is initially <self> == default config settings
-        # fromDict contains all configurations from the user config file
-
-        # update all available fields from fromDict
-        for k in fromDict.keys():
-            # if both source and destination types are dicts: traverse
-            if ((type(fromDict[k]) is DictType) and (type(toDict[k]) is DictType)):
-                # recurse
-                self.selfUpdate(toDict[k], fromDict[k])
-
-            # if value is no dictionary: use value from config file
-            elif (not type(fromDict[k]) is ModuleType):
-                toDict[k] = fromDict[k]
-
-        
     def save(self):
         """saves the current version of user settings"""
         # target folder does not exist: create
@@ -666,7 +709,7 @@ class _Pref(dict):
                     'defaultHistory', 'addHistoryFromRecords', 'recordDefault',
                     'autoScanAutoMountOnNew', 'autoScanOnNew', 'autoScriptOnNew',
                     'deepcopyOnCopy', 'defaultFile', 'reopenLastFile',
-                    'recentFiles']:
+                    'recentFiles', 'queryPathOnLinkedImage', 'version']:
             self[key] = deepcopy(pref[key])
 
         # debug info on a per-class basis
