@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 186 $
+# Revision: $Rev: 209 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -49,7 +49,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("lmc.py - Moviefly  $Rev: 186 $ (c) by Uwe Mayer")
+log.info("lmc.py - Moviefly  $Rev: 209 $ (c) by Uwe Mayer")
 
 
 #-- own imports --
@@ -635,6 +635,16 @@ class LMCMain(LMCWidgetBase):
         self.centralWidget().saveAsPicture()
         
 
+    def moviePictureLink(self):
+        """called when linking a picture (vs. embedding it)"""
+        self.centralWidget().linkPicture()
+
+
+    def moviePictureEmbed(self):
+        """called when embedding a picture (vs. linking it)"""
+        self.centralWidget().embedPicture()
+    
+
     def movieGetLocalFromFiles(self):
         """get information from a file"""
         # select filenames
@@ -834,7 +844,7 @@ class LMCMain(LMCWidgetBase):
             record[f] = new[f]
         self.centralWidget().setCurrentRecord(record) # display new values
         if (new.has_key('picture')): 
-            self.centralWidget().image.imageDecode()
+            self.centralWidget().defaultImageDecode()
                     
         # focus first field on AMCForm
         self.centralWidget().form.focus("mediaLabel")
@@ -880,7 +890,7 @@ class LMCMain(LMCWidgetBase):
         
         if (pref['deepcopyOnCopy']):
             self.log.debug("Creating deepcopy of image")
-            self.centralWidget().image.imageDecode()
+            self.centralWidget().defaultImageDecode()
             
 
     def movieFind(self):
@@ -920,6 +930,7 @@ class LMCMain(LMCWidgetBase):
         self.centralWidget().changeNumber(mode, number)
         
 
+
     #-- helper methods ---------------------------------------------------------
     def _updateRecentFiles(self):
         # remove recent files in the menu
@@ -1118,6 +1129,12 @@ class LMCMain(LMCWidgetBase):
 
         self.connect(self.movieChangeNumberAction, SIGNAL("activated()"), self.movieChangeNumber)
         self.movieChangeNumberAction.setEnabled(True)
+
+        self.connect(self.moviePictureLinkAction, SIGNAL("activated()"), self.moviePictureLink)
+        self.moviePictureLinkAction.setEnabled(True)
+        
+        self.connect(self.moviePictureEmbedAction, SIGNAL("activated()"), self.moviePictureEmbed)
+        self.moviePictureEmbedAction.setEnabled(True)
         
         self.recordActionsEnabled = True
         
@@ -1163,7 +1180,13 @@ class LMCMain(LMCWidgetBase):
 
         self.movieChangeNumberAction.setEnabled(False)
         self.disconnect(self.movieChangeNumberAction, SIGNAL("activated()"), self.movieChangeNumber)
+
+        self.moviePictureLinkAction.setEnabled(False)     
+        self.disconnect(self.moviePictureLinkAction, SIGNAL("activated()"), self.moviePictureLink)
         
+        self.moviePictureEmbedAction.setEnabled(False)
+        self.disconnect(self.moviePictureEmbedAction, SIGNAL("activated()"), self.moviePictureEmbed)
+
         self.recordActionsEnabled = False
 
 
@@ -1222,7 +1245,7 @@ Synopsis: lmc.py [-h|--help] [<input-file>]
 elif (('-v' in app.argv()[1:]) or ('--version' in app.argv()[1:])):
     print "Moviefly  (c) by Uwe Mayer"
     print "Version:  %s"%version
-    print "Revision: $Rev: 186 $"
+    print "Revision: $Rev: 209 $"
     print 
     sys.exit()
     
